@@ -1,4 +1,4 @@
-/* $Id: rrd_helpers.c,v 1.15 2003/03/07 01:32:36 sacerdoti Exp $ */
+/* $Id: rrd_helpers.c,v 1.21 2003/05/29 22:13:17 sacerdoti Exp $ */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -12,13 +12,13 @@
 #include <time.h>
 
 #define PATHSIZE 4096
-extern char * rrd_rootdir;
+extern gmetad_config_t gmetad_config;
 
 
 pthread_mutex_t rrd_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static void inline
-my_mkdir ( char *dir )
+my_mkdir ( const char *dir )
 {
    if ( mkdir ( dir, 0755 ) < 0 && errno != EEXIST)
       {
@@ -27,17 +27,12 @@ my_mkdir ( char *dir )
 }
 
 static int
-RRD_update( char *rrd, char *sum, char *num, unsigned int process_time )
+RRD_update( char *rrd, const char *sum, const char *num, unsigned int process_time )
 {
    char *argv[3];
    int   argc = 3;
    char val[128];
 
-   /*  if process_time is undefined, we set it to the current time */
-
-   if (!process_time)
-      process_time = time(0);
-
    /* If we are a host RRD, we "sum" over only one host. */
    if (num)
       sprintf(val, "%d:%s:%s", process_time, sum, num);
@@ -54,11 +49,11 @@ RRD_update( char *rrd, char *sum, char *num, unsigned int process_time )
    rrd_update(argc, argv);
    if(rrd_test_error())
       {
-         err_msg("RRD_update: %s", rrd_get_error());
+         err_msg("RRD_update (%s): %s", rrd, rrd_get_error());
          pthread_mutex_unlock( &rrd_mutex );
          return 1;
       } 
-   debug_msg("Updated rrd %s with value %s", rrd, val);
+   /* debug_msg("Updated rrd %s with value %s", rrd, val); */
    pthread_mutex_unlock( &rrd_mutex );
    return 0;
 }
@@ -66,23 +61,26 @@ RRD_update( char *rrd, char *sum, char *num, unsigned int process_time )
 
 /* Warning: RRD_create will overwrite a RRdb if it already exists */
 static int
-RRD_create( char *rrd, int summary, unsigned int step)
+RRD_create( char *rrd, int summary, unsigned int step, unsigned int process_time)
 {
    char *argv[15];
    int  argc=0;
    int heartbeat;
-   char s[16];
+   char s[16], start[64];
    char sum[64];
    char num[64];
 
    /* Our heartbeat is twice the step interval. */
-   heartbeat = 2*step;
+   heartbeat = 8*step;
 
    argv[argc++] = "dummy";
    argv[argc++] = rrd;
    argv[argc++] = "--step";
    sprintf(s, "%u", step);
    argv[argc++] = s;
+   argv[argc++] = "--start";
+   sprintf(start, "%u", process_time-1);
+   argv[argc++] = start;
    sprintf(sum,"DS:sum:GAUGE:%d:U:U", heartbeat);
    argv[argc++] = sum;
    if (summary) {
@@ -114,12 +112,17 @@ RRD_create( char *rrd, int summary, unsigned int step)
 /* A summary RRD has a "num" and a "sum" DS (datasource) whereas the
    host rrds only have "sum" (since num is always 1) */
 static int
-push_data_to_rrd( char *rrd, char *sum, char *num, unsigned int step, unsigned int process_time)
+push_data_to_rrd( char *rrd, const char *sum, const char *num, 
+   unsigned int step, unsigned int process_time)
 {
    int rval;
    int summary;
    struct stat st;
 
+   /*  if process_time is undefined, we set it to the current time */
+   if (!process_time)
+      process_time = time(0);
+
    if (num)
       summary=1;
    else
@@ -127,7 +130,7 @@ push_data_to_rrd( char *rrd, char *sum, char *num, unsigned int step, unsigned i
 
    if( stat(rrd, &st) )
       {
-         rval = RRD_create( rrd, summary, step );
+         rval = RRD_create( rrd, summary, step, process_time );
          if( rval )
             return rval;
       }
@@ -137,13 +140,14 @@ push_data_to_rrd( char *rrd, char *sum, char *num, unsigned int step, unsigned i
 
 /* Assumes num argument will be NULL for a host RRD. */
 int
-write_data_to_rrd ( char *source, char *host, char *metric, char *sum, char *num, unsigned int step, unsigned int process_time )
+write_data_to_rrd ( const char *source, const char *host, const char *metric, 
+   const char *sum, const char *num, unsigned int step, unsigned int process_time )
 {
    char rrd[ PATHSIZE ];
    char *summary_dir = "__SummaryInfo__";
 
    /* Build the path to our desired RRD file. Assume the rootdir exists. */
-   strcpy(rrd, rrd_rootdir);
+   strcpy(rrd, gmetad_config.rrd_rootdir);
 
    if (source) {
       strncat(rrd, "/", PATHSIZE);
