@@ -1,4 +1,4 @@
-/* $Id: gmond.c,v 1.26 2003/01/07 17:05:04 massie Exp $ */
+/* $Id: gmond.c,v 1.28 2003/07/23 02:05:41 pmsmith Exp $ */
 #include "interface.h"
 #include "gangliaconf.h"
 #include "dotconf.h"
@@ -162,6 +162,12 @@ main ( int argc, char *argv[] )
    /*
    print_gmond_config();
    */
+   /* in machine.c */
+   initval = metric_init();
+   if ( initval.int32 <0)
+      {
+         err_quit("metric_init() returned an error");
+      }
 
    if(!gmond_config.no_setuid)
       become_a_nobody(gmond_config.setuid);
@@ -259,20 +265,14 @@ main ( int argc, char *argv[] )
    if(! gmond_config.mute )
       {
          mcast_socket = g_mcast_out ( gmond_config.mcast_channel, gmond_config.mcast_port,  
-                                      (struct in_addr *)&(entry->intf_addr.addr_ip), gmond_config.mcast_ttl);
+                             (struct in_addr *)&(entry->intf_addr.addr_ip), gmond_config.mcast_ttl);
          if ( !mcast_socket )
             {
                perror("gmond could not connect to multicast channel");
                return -1;
             }
-         debug_msg("multicasting on channel %s %d", gmond_config.mcast_channel, gmond_config.mcast_port);
-
-         /* in machine.c */
-         initval = metric_init();
-         if ( initval.int32 <0)
-            {
-               err_quit("monitor_init() returned an error");
-            }
+         debug_msg("multicasting on channel %s %d", 
+		    gmond_config.mcast_channel, gmond_config.mcast_port);
 
          pthread_create(&tid, &attr, monitor_thread, NULL);
          debug_msg("created monitor thread");
