@@ -1,4 +1,4 @@
-/* $Id: listen.c,v 1.14 2003/03/07 01:31:01 sacerdoti Exp $ */
+/* $Id: listen.c,v 1.15 2004/01/20 19:15:23 sacerdoti Exp $ */
 #include <ganglia.h>
 #include <ganglia/hash.h>
 #include <ganglia/barrier.h>
@@ -83,8 +83,7 @@ pre_process_node( struct sockaddr_in *in, unsigned int key, XDR *xhandle)
          debug_msg("pre_process_node() has set the timestamp");
 
          data.tmax = metric[heartbeat].mcast_max;
-         /* Hosts are never deleted for now. */
-         data.dmax = 0;
+         data.dmax = gmond_config.host_dmax;
 
          data.hashp = hash_create(num_key_metrics);
          if (data.hashp == NULL)
