@@ -178,7 +178,7 @@ os_name_func ( void )
   
    if( -1 == uname(&uts))
       {
-      err_ret("machine_type_func() got an error from uname()");
+      err_ret("os_name_func() got an error from uname()");
       strncpy( val.str, "HP-UX", MAX_G_STRING_SIZE);
       }
    else
@@ -195,7 +195,7 @@ os_release_func ( void )
 
    if( -1 == uname(&uts))
       {
-      err_ret("machine_type_func() got an error from uname()");
+      err_ret("os_release_func() got an error from uname()");
       strncpy( val.str, "unknown", MAX_G_STRING_SIZE);
       }
    else
@@ -422,7 +422,7 @@ load_func ( int which)
          case LOAD_5:  val.f = p.psd_avg_5_min;  break;
          case LOAD_15: val.f = p.psd_avg_15_min; break;
          default:
-           err_sys("swap_func() - invalid value for which = %d", which);
+           err_sys("load_func() - invalid value for which = %d", which);
          }
 
    return val;
