@@ -5,7 +5,7 @@
 
 extern metric_t metric[];
 
-#define rand_int(__min,__max) __min + ( __max * rand()/(RAND_MAX+1.0))
+#define rand_int(__min,__max) __min + (((double)(__max-__min))*rand()/(RAND_MAX+1.0))
 
 extern g_mcast_socket * mcast_socket;
 extern pthread_mutex_t mcast_socket_mutex;
