@@ -1,4 +1,4 @@
-/* $Id: server.c,v 1.19 2003/06/04 17:37:01 sacerdoti Exp $ */
+/* $Id: server.c,v 1.20 2003/12/31 20:12:45 massie Exp $ */
 #include <ganglia.h>
 #include <ganglia/barrier.h>
 #include <ganglia/gmond_config.h>
@@ -64,6 +64,12 @@ data_report ( datum_t *key, datum_t *val, void *arg )
 {
    client_t *client = (client_t *)arg;
    metric_data_t *metric = (metric_data_t *) val->data;
+   long tn;
+
+   tn = (client->timestamp).tv_sec - metric->timestamp.tv_sec;
+   /* Important that TN is never a negative number - matt */
+   if(tn < 0)
+      tn = 0;
 
    return buffrd_print( client, "<METRIC NAME=\"%s\" VAL=\"%s\" TYPE=\"%s\" UNITS=\"%s\" "
                         "TN=\"%ld\" TMAX=\"%lu\" DMAX=\"%lu\" SLOPE=\"%s\" SOURCE=\"gmond\"/>\n",
@@ -71,7 +77,7 @@ data_report ( datum_t *key, datum_t *val, void *arg )
                           (char *) metric->val,
                           (char *) metric->type,
                           (char *) metric->units,
-                          (client->timestamp).tv_sec - metric->timestamp.tv_sec,
+                          tn,
                           (unsigned long) metric->tmax,
                           (unsigned long) metric->dmax,
                           (char *) metric->slope);
@@ -82,14 +88,20 @@ user_data_report ( datum_t *key, datum_t *val, void *arg )
 {
    client_t *client = (client_t *)arg;
    metric_data_t *metric = (metric_data_t *) val->data;
+   long tn;
 
+   tn = (client->timestamp).tv_sec - metric->timestamp.tv_sec;
+   /* TN should never be negative - matt */
+   if(tn < 0)
+      tn = 0;
+ 
    return buffrd_print( client, "<METRIC NAME=\"%s\" VAL=\"%s\" TYPE=\"%s\" UNITS=\"%s\" "
                         "TN=\"%ld\" TMAX=\"%lu\" DMAX=\"%lu\" SLOPE=\"%s\" SOURCE=\"gmetric\"/>\n",
                        (char *) key->data,
                        (char *) metric->val,
                        (char *) metric->type,
                        (char *) metric->units,
-                       (client->timestamp).tv_sec - metric->timestamp.tv_sec,
+                       tn,
                        (unsigned long) metric->tmax,
                        (unsigned long) metric->dmax,
                        (char *) metric->slope);
@@ -100,13 +112,20 @@ node_report ( datum_t *key, datum_t *val, void *arg )
 {
    client_t *client  = (client_t *)arg;
    node_data_t * node = (node_data_t *) val->data;
+   long tn;
+
+   tn =  (client->timestamp).tv_sec - node->timestamp.tv_sec;
+   /* make sure the TN is never a negative number - matt */
+   if( tn < 0 )
+       tn = 0;
+
 
    if (buffrd_print( client, "<HOST NAME=\"%s\" IP=\"%s\" REPORTED=\"%ld\" "
                         "TN=\"%ld\" TMAX=\"%lu\" DMAX=\"%lu\" LOCATION=\"%s\" GMOND_STARTED=\"%u\">\n",
                   (char *) node->hostname,
                   (char *) key->data,
                   node->timestamp.tv_sec,
-                  (client->timestamp).tv_sec - node->timestamp.tv_sec,
+                  tn,
                   (unsigned long) node->tmax,
                   (unsigned long) node->dmax,
                   (char *) node->location,
