@@ -1,7 +1,7 @@
 /**
  * @file debug_msg.c Debug Message function
  */
-/* $Id: debug_msg.c,v 1.2 2002/06/20 03:23:24 massie Exp $ */
+/* $Id: debug_msg.c,v 1.4 2003/05/06 17:49:23 sacerdoti Exp $ */
 #include "gangliaconf.h"
 
 int debug_level = 0;
@@ -15,7 +15,7 @@ int debug_level = 0;
 void
 debug_msg(const char *format, ...)
 {
-   if (debug_level)
+   if (debug_level > 1 && format)
       {
          va_list ap;
          va_start(ap, format);
